@@ -2,10 +2,17 @@ class APIKeyNotSetError(Exception):
     pass
 
 
+class APIBaseError(Exception):
+    pass
+
+
 class HypervectorError(Exception):
     def __init__(self, response=None):
         self.response = response
-        self.status_code = response.status_code
+        if response:
+            self.status_code = response.status_code
+        else:
+            self.status_code = None
 
 
 
