@@ -3,6 +3,7 @@ import json
 import requests
 
 import hypervector
+from hypervector.resources.auxilliary.revision import Revision
 from hypervector.resources.core.ensemble import Ensemble
 from hypervector.resources.abstract.api_resource import APIResource
 
@@ -22,7 +23,7 @@ class Definition(APIResource):
             definition_uuid=dictionary['definition_uuid'],
             definition_name=dictionary['definition_name'],
             added=dictionary['added'],
-            ensembles=None
+            ensembles=_parse_ensembles(dictionary['ensembles'])
         )
 
     def to_response(self):
@@ -37,10 +38,14 @@ class Definition(APIResource):
     def from_get(cls, response):
         return cls.from_response(response.json())
 
+    def refresh(self):
+        definition = self.get(self.definition_uuid)
+        self.__dict__.update(definition.__dict__)
+
     @classmethod
     def list(cls):
         endpoint = f"{hypervector.API_BASE}/definitions"
-        response = requests.get(endpoint, headers=cls.get_headers()).json()
+        response = cls.request(endpoint)
         return [cls.from_response(definition) for definition in response]
 
     @classmethod
@@ -53,14 +58,23 @@ class Definition(APIResource):
         response = requests.post(endpoint, json=data, headers=cls.get_headers()).json()
         return cls.from_response(response)
 
+    def history(self):
+        endpoint = f"{hypervector.API_BASE}/definition/{self.definition_uuid}/history"
+        response = requests.get(endpoint, headers=self.get_headers()).json()
+        history = [Revision.from_response(response_item) for response_item in response]
+        return history
+
 
 def _parse_definition_from_json_file(definition_json_file):
     return json.load(open(definition_json_file, 'rb'))
 
 
 def _parse_ensembles(ensembles):
+    if not ensembles or len(ensembles) == 0:
+        return None
+
     parsed_ensembles = []
-    for ensemble_uuid, ensemble_meta in ensembles.items():
-        parsed_ensemble = Ensemble.from_dict(ensemble_uuid, ensemble_meta)
+    for ensemble in ensembles:
+        parsed_ensemble = Ensemble.from_response(ensemble)
         parsed_ensembles.append(parsed_ensemble)
     return parsed_ensembles
