@@ -46,11 +46,15 @@ class Ensemble(APIResource):
     def from_get(cls, response):
         return cls.from_response(response.json())
 
+    def refresh(self):
+        ensemble = self.get(self.ensemble_uuid)
+        self.__dict__.update(ensemble.__dict__)
+
     @classmethod
     def list(cls, definition):
         parent_endpoint = f"{hypervector.API_BASE}/definition/{definition.definition_uuid}"
         endpoint = f"{parent_endpoint}/ensembles"
-        response = requests.get(endpoint, headers=cls.get_headers()).json()
+        response = cls.request(endpoint)
         return [cls.from_response(ensemble) for ensemble in response]
 
     @classmethod
